@@ -26,6 +26,8 @@
 
 #include <algorithm>
 
+using namespace Qt::Literals::StringLiterals;
+
 QList<QUrl> M3uPlaylistParser::fromPlaylist(const QUrl &fileName, const QByteArray &fileContent) {
     Q_UNUSED(fileName);
     QList<QUrl> result;
@@ -342,6 +344,7 @@ void MediaPlayListProxyModel::setRepeatMode(Repeat value)
         d->mRepeatMode = value;
         Q_EMIT repeatModeChanged();
         Q_EMIT remainingTracksChanged();
+        Q_EMIT remainingTracksDurationChanged();
         Q_EMIT persistentStateChanged();
         determineAndNotifyPreviousAndNextTracks();
     }
@@ -457,6 +460,7 @@ void MediaPlayListProxyModel::setShuffleMode(const MediaPlayListProxyModel::Shuf
         }
         Q_EMIT shuffleModeChanged();
         Q_EMIT remainingTracksChanged();
+        Q_EMIT remainingTracksDurationChanged();
         Q_EMIT persistentStateChanged();
     }
 }
@@ -646,7 +650,9 @@ void MediaPlayListProxyModel::sourceRowsInserted(const QModelIndex &parent, int
     }
 
     Q_EMIT tracksCountChanged();
+    Q_EMIT totalTracksDurationChanged();
     Q_EMIT remainingTracksChanged();
+    Q_EMIT remainingTracksDurationChanged();
     Q_EMIT persistentStateChanged();
 }
 
@@ -707,7 +713,9 @@ void MediaPlayListProxyModel::sourceRowsRemoved(const QModelIndex &parent, int s
         determineAndNotifyPreviousAndNextTracks();
     }
     Q_EMIT tracksCountChanged();
+    Q_EMIT totalTracksDurationChanged();
     Q_EMIT remainingTracksChanged();
+    Q_EMIT remainingTracksDurationChanged();
     Q_EMIT persistentStateChanged();
 }
 
@@ -727,6 +735,7 @@ void MediaPlayListProxyModel::sourceRowsMoved(const QModelIndex &parent, int sta
     Q_UNUSED(destRow);
     endMoveRows();
     Q_EMIT remainingTracksChanged();
+    Q_EMIT remainingTracksDurationChanged();
     Q_EMIT persistentStateChanged();
 }
 
@@ -745,6 +754,8 @@ void MediaPlayListProxyModel::sourceDataChanged(const QModelIndex &topLeft, cons
     auto endSourceRow = bottomRight.row();
     for (int i = startSourceRow; i <= endSourceRow; i++) {
         Q_EMIT dataChanged(index(mapRowFromSource(i), 0), index(mapRowFromSource(i), 0), roles);
+        Q_EMIT remainingTracksDurationChanged();
+        Q_EMIT totalTracksDurationChanged();
         if (i == d->mCurrentTrack.row()) {
             Q_EMIT currentTrackDataChanged();
         } else if (i == d->mNextTrack.row()) {
@@ -771,6 +782,24 @@ void MediaPlayListProxyModel::sourceHeaderDataChanged(Qt::Orientation orientatio
     Q_EMIT headerDataChanged(orientation, first, last);
 }
 
+int MediaPlayListProxyModel::totalTracksDuration() const
+{
+    int time = 0;
+    for (int i = 0; i < rowCount(); i++) {
+        time += d->mPlayListModel->data(index(i, 0), MediaPlayList::DurationRole).toTime().msecsSinceStartOfDay();
+    }
+    return time;
+}
+
+int MediaPlayListProxyModel::remainingTracksDuration() const
+{
+    int time = 0;
+    for (int i = d->mCurrentTrack.row(); i < rowCount(); i++) {
+        time += d->mPlayListModel->data(index(i, 0), MediaPlayList::DurationRole).toTime().msecsSinceStartOfDay();
+    }
+    return time;
+}
+
 int MediaPlayListProxyModel::remainingTracks() const
 {
     if (!d->mCurrentTrack.isValid() || (d->mRepeatMode == Repeat::One) || (d->mRepeatMode == Repeat::Playlist)) {
@@ -780,6 +809,17 @@ int MediaPlayListProxyModel::remainingTracks() const
     }
 }
 
+int MediaPlayListProxyModel::radioCount() const
+{
+    int count = 0;
+    for (int i = 0; i < rowCount(); i++) {
+        if (d->mPlayListModel->data(index(i, 0), MediaPlayList::ElementTypeRole) == ElisaUtils::Radio) {
+            count++;
+        }
+    }
+    return count;
+}
+
 int MediaPlayListProxyModel::tracksCount() const
 {
     return rowCount();
@@ -934,6 +974,7 @@ void MediaPlayListProxyModel::notifyCurrentTrackRowChanged()
     determineAndNotifyPreviousAndNextTracks();
     Q_EMIT currentTrackRowChanged();
     Q_EMIT remainingTracksChanged();
+    Q_EMIT remainingTracksDurationChanged();
 }
 
 void MediaPlayListProxyModel::notifyCurrentTrackChanged()
@@ -1215,6 +1256,7 @@ void MediaPlayListProxyModel::restoreShuffleMode(MediaPlayListProxyModel::Shuffl
 
         Q_EMIT shuffleModeChanged();
         Q_EMIT remainingTracksChanged();
+        Q_EMIT remainingTracksDurationChanged();
     }
 }
 
@@ -1234,7 +1276,7 @@ bool MediaPlayListProxyModel::canOpenLoadedPlaylist() const
 void MediaPlayListProxyModel::openLoadedPlayList()
 {
 #if KFKIO_FOUND
-    auto job = new KIO::OpenUrlJob(d->mLoadedPlayListUrl, QLatin1String("text/plain"));
+    auto job = new KIO::OpenUrlJob(d->mLoadedPlayListUrl, u"text/plain"_s);
     job->start();
 #endif
 }
